@@ -4,9 +4,12 @@ use strict;
 use warnings;
 use Exporter;
 
+use File::Find::Rule;
+use File::Spec;
+
 use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
 
-our $VERSION = '1.76';
+our $VERSION = '1.77';
 
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(os_is os_isnt die_if_os_is die_if_os_isnt die_unsupported list_platforms list_family_members);
@@ -166,12 +169,6 @@ should Just Work anyway.
 my ($re_Devel, $re_AssertOS);
 
 sub list_platforms {
-    eval " # only load these if needed
-        use File::Find::Rule;
-        use File::Spec;
-    ";
-    
-    die($@) if($@);
     if (!$re_Devel) {
         my $case_flag = File::Spec->case_tolerant ? '(?i)' : '';
         $re_Devel    = qr/$case_flag ^Devel$/x;
